use comunic_server::data::config::{conf, Config};
use comunic_server::helpers::database;
use comunic_server::controllers::server;
use comunic_server::helpers::database::QueryInfo;

#[derive(Debug)]
struct User {
    id : i64,
    name: String,
}

#[actix_rt::main]
async fn main() -> std::io::Result<()> {

    // Load configuration
    Config::load("config.yaml").expect("Could not load configuration!");

    // Connect to the database
    database::connect(&conf().database).expect("Could not connect to database!");

    let mut query = QueryInfo::new("user");
    query.cond("age", "190");
    //query.cond("id", "1");
    let res = database::query_row(query, |res| Ok(User {
        id: res.get_int64("id")?,
        name: res.get_str("name")?,
    })).unwrap();

    println!("{:#?}", res);

    // Start the server
    server::start_server(conf()).await
}
